# tornado_discovery

Just a pure python3 module for service discovery.

# install
```bash
$ cd ./tornado_discovery
$ python3 ./setup.py install
```

# test
```bash
# run listener
$ cd ./tornado_discovery/test
$ python3 ./test_discovery_listener.py

# run registrant
$ cd ./tornado_discovery/test
$ python3 ./test_discovery_registrant.py
```

